﻿using GrapeCity.Documents.Pdf;

namespace GcPdfViewerSupportApi.Models
{

    /// <summary>
    /// Information about opened document.
    /// </summary>
    public class OpenedDocumentInfo
    {

        /// <summary>
        /// Constructor.
        /// </summary>
        /// <param name="documentInfo"></param>
        /// <param name="pagesCount"></param>
        /// <param name="docId"></param>
        /// <param name="defaultViewPortSize"></param>
        public OpenedDocumentInfo(DocumentInfo documentInfo, int pagesCount, string docId, System.Drawing.SizeF defaultViewPortSize)
        {
            this.docId = docId;
            this.info = documentInfo;
            this.pagesCount = pagesCount;
            this.defaultViewPortSize = new { w = defaultViewPortSize.Width, h = defaultViewPortSize.Height };
        }

        /// <summary>
        /// Unique document session identifier.
        /// </summary>
        public string docId { get; set; }

        /// <summary>
        /// Pages count.
        /// </summary>
        public int pagesCount { get; set; }

        /// <summary>
        /// Viewport size.
        /// </summary>
        public dynamic defaultViewPortSize { get; set; }

        /// <summary>
        /// Contains information about the document. This information includes 
        /// the document author, title, keywords, etc.
        /// </summary>
        public DocumentInfo info { get; set; }

    }
}
